@@ -274,7 +274,7 @@ class LanguageContainer:
 		
 		try:
 			snippets[value].remove(snippet)
-		except:
+		except IndexError:
 			True
 		
 	def append(self, snippet):
@@ -291,7 +291,7 @@ class LanguageContainer:
 	def remove(self, snippet):
 		try:
 			self.snippets.remove(snippet)
-		except:
+		except IndexError:
 			True
 			
 		self._remove_prop(snippet, 'tag')
@@ -527,12 +527,12 @@ class SnippetsUserFile(SnippetsSystemFile):
 		try:
 			self.root.remove(element)
 			self.tainted = True
-		except:
+		except ValueError:
 			return
 		
 		try:
 			first = self.root[0]
-		except:
+		except IndexError:
 			# No more elements, this library is useless now
 			SnippetsLibrary().remove_library(self)
 	
@@ -550,7 +550,7 @@ class SnippetsUserFile(SnippetsSystemFile):
 			sys.stderr.write("Error in making dirs\n")
 
 		try:
-			et.ElementTree(self.root).write(self.path, 'utf-8')
+			write_xml(self.root, self.path, ('text', 'accelerator'))
 			self.tainted = False
 		except IOError:
 			# Couldn't save, what to do
@@ -564,6 +564,7 @@ class SnippetsUserFile(SnippetsSystemFile):
 class SnippetsLibraryImpl:
 	def __init__(self):
 		self._accelerator_activated_cb = None
+		
 		self.loaded = False
 			
 	def set_dirs(self, userdir, systemdirs):
@@ -817,7 +818,7 @@ class SnippetsLibraryImpl:
 		# Ensure language as well as the global snippets (None)
 		for lang in (None, language):
 			if lang in self.libraries:
-			# Ensure the container exists
+				# Ensure the container exists
 				self.container(lang)
 
 				for library in self.libraries[lang]:
